@@ -7,12 +7,12 @@ use strict;
 
 package XML::Compile::Transport::SOAPHTTP;
 use vars '$VERSION';
-$VERSION = '0.78';
+$VERSION = '2.00_01';
 
 use base 'XML::Compile::Transport';
 
 use Log::Report 'xml-compile-soap', syntax => 'SHORT';
-use XML::Compile::SOAP::Util qw/SOAP11ENV/;
+use XML::Compile::SOAP::Util qw/:http/;
 
 use LWP            ();
 use LWP::UserAgent ();
@@ -20,13 +20,23 @@ use HTTP::Request  ();
 use HTTP::Headers  ();
 
 use XML::LibXML   ();
-use Encode;
+
+if($] >= 5.008003)
+{   use Encode;
+    Encode->import;
+}
+else
+{   *encode = sub { $_[1] };
+}
 
 my $parser = XML::LibXML->new;
 
 # (Microsofts HTTP Extension Framework)
 my $http_ext_id = SOAP11ENV;
 
+XML::Compile->knownNamespace(&WSDL11HTTP => 'wsdl-http.xsd');
+__PACKAGE__->register(SOAP11HTTP);
+
 
 sub init($)
 {   my ($self, $args) = @_;
@@ -40,6 +50,15 @@ sub init($)
     $self;
 }
 
+sub _initWSDL11($)
+{   my ($class, $wsdl) = @_;
+    trace "initialize SOAPHTTP transporter for WSDL11";
+
+    $wsdl->importDefinitions(WSDL11HTTP, elementFormDefault => 'qualified');
+    $wsdl->prefixes(http => WSDL11HTTP);
+    $class->register('HTTP');   # register alias
+}
+
 #-------------------------------------------
 
 
@@ -120,9 +139,9 @@ sub _prepare_call($)
       $hook
     ? sub  # hooked code
       { my $trace = $_[1];
-        my $u = encode($charset, $_[0]);
-        $request->content($u);
-        { use bytes; $request->header('Content-Length' => length $u); }
+        $request->content($_[0]);   # already bytes (not utf-8)
+
+        { use bytes; $request->header('Content-Length' => length $_[0]); }
  
         $trace->{http_request}  = $request;
         $trace->{action}        = $action;
@@ -136,16 +155,16 @@ sub _prepare_call($)
 
         $trace->{http_response} = $response;
 
+        # HTTP::Message::decoded_content() does not work for old Perls
           defined $response && $response->content_type =~ m![/+]xml$!i
-        ? $response->decoded_content
+        ? ($] >= 5.008 ? $response->decoded_content : $response->content)
         : undef;
       }
 
     : sub  # normal code
       { my $trace = $_[1];
-        my $u = encode($charset, $_[0]);
-        $request->content($u);
-        { use bytes; $request->header('Content-Length' => length $u); }
+        $request->content($_[0]);
+        { use bytes; $request->header('Content-Length' => length $_[0]); }
 
         $trace->{http_request}  = $request;
 
@@ -153,6 +172,11 @@ sub _prepare_call($)
             or return undef;
 
         $trace->{http_response} = $response;
+        if($response->is_error)
+        {   error   $response->message if $response->header('Client-Warning');
+            warning $response->message;
+            return undef;
+        }
 
           $response->content_type =~ m![/+]xml$!i
         ? $response->decoded_content
